@@ -1,4 +1,4 @@
-/***             analog 5.23             http://www.analog.cx/             ***/
+/***             analog 5.24             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -71,7 +71,7 @@ choice do_alias(char *name, Memman *mp, Alias *aliashead, char *dirsuffix,
  * In either case, the function returns whether any alias matched.
  */
 logical do_aliasx(FILE *outf, Outchoices *od, char *name, Alias *aliashead) {
-  ptrdiff_t pmatch[PMATCH_SIZE];
+  int pmatch[PMATCH_SIZE];
   Alias *ap;
   logical done;
 
@@ -486,28 +486,50 @@ logical do_aliasb(char *name) {
 
   if (headmatch(name, "Mozilla")) {
     if (*(name + 7) == '/' && *(name + 8) == '5') {
+
       /* Mozilla/5 is messy. The real version number should be written at the
 	 end of the brackets. Furthermore, there are (so far) three different
 	 version number formats, "m18", "0.8" and "rv:0.9.1+".
+
+	 To add to the confusion, we should spot those which are Netscape 6+
+	 branded, which have the normal Mozilla version number but also the
+	 brand name on the end.
 	 
 	 We've filtered out Mozilla/5.0 (compatible) in Bnextname() so these
 	 should all be genuine Mozilla. But if we can't find a version number
 	 we'll just leave it as Mozilla, not Mozilla/5.0, to avoid confusing
 	 the two different numbering schemes. */
-      if ((t = strstr(name, ") Gecko")) != NULL) {
+
+      if ((t = strstr(name, ") Gecko/")) != NULL) {
 	/* There should only be one ')', but let's be cautious. */
-	for (s = t - 1; *s != ' ' && s != name; s--)
-	  ;  /* run back to space before last element inside brackets */
-	if (s != name && *(s - 1) == ';') {
-	  s++;
-	  if (headmatch(s, "rv:"))
-	    s += 3;
-	  if (ISDIGIT(*s) || (*s == 'm' && ISDIGIT(*(s + 1)))) { /* Found it */
-	    if (*s == 'm')
-	      *s = 'M';
-	    memcpy(name + 8, s, t - s);
-	    *(name + 8 + (t - s)) = '\0';
-	    done = TRUE;
+
+	/* First try pulling off Netscape version number. There are two cases:
+	   Netscape/7.x, or Netscape6/6.x which should be translated to just
+	   Netscape/6.x. */
+	if (headmatch(t + 17 /* after "Gecko/YYYYMMDD" */, "Netscape")) {
+	  memmove(name, t + 17, 8);
+	  if (*(t + 25) == '6' && *(t + 26) == '/')
+	    memmove(name + 8, t + 26, strlen(t + 26) + 1);
+	  else
+	    memmove(name + 8, t + 25, strlen(t + 25) + 1);
+	  done = TRUE;
+	}
+
+	/* Otherwise look for normal Mozilla version number */
+	else {
+	  for (s = t - 1; *s != ' ' && s != name; s--)
+	    ;  /* run back to space before last element inside brackets */
+	  if (s != name && *(s - 1) == ';') {
+	    s++;
+	    if (headmatch(s, "rv:"))
+	      s += 3;
+	    if (ISDIGIT(*s) || (*s == 'm' && ISDIGIT(*(s + 1)))) {/* Found it*/
+	      if (*s == 'm')
+		*s = 'M';
+	      memcpy(name + 8, s, t - s);
+	      *(name + 8 + (t - s)) = '\0';
+	      done = TRUE;
+	    }
 	  }
 	}
       }
@@ -528,10 +550,6 @@ logical do_aliasb(char *name) {
     return(TRUE);
   }
 
-  /* Netscape6 is actually Netscape */
-  else if (headmatch(name, "Netscape6"))
-    memmove(name + 8, name + 9, strlen(name + 9) + 1);
-
   /* In general, convert "Name n.m" to "Name/n.m" if n a digit */
   for (s = name; ISALNUM(*s); s++)
     ;
@@ -683,7 +701,7 @@ void do_dns(char *name, char *alias, choice level) {
 
 /* Print the alias of a name to outf. Matching has already been checked. */
 void printalias(FILE *outf, Outchoices *od, char *name, AliasTo *to,
-		ptrdiff_t pmatch[]) {
+		int pmatch[]) {
   char c;
 
   for ( ; to != NULL; TO_NEXT(to)) {
@@ -700,9 +718,9 @@ void printalias(FILE *outf, Outchoices *od, char *name, AliasTo *to,
 
 /* Change name to its alias. Matching has already been checked.
    name MUST have length >= BLOCKSIZE. */
-void wildalias(char *name, AliasTo *to, ptrdiff_t pmatch[]) {
+void wildalias(char *name, AliasTo *to, int pmatch[]) {
   char *s, *ans;
-  ptrdiff_t *pm;
+  int *pm;
   size_t len, tolen;
 
   len = strlen(name);
