@@ -1,4 +1,4 @@
-/***             analog 5.23             http://www.analog.cx/             ***/
+/***             analog 5.24             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -14,7 +14,7 @@
 
 /*** OS specific things ***/
 
-#define VNUMBER "5.23"    /* the version number of this program */
+#define VNUMBER "5.24"    /* the version number of this program */
 
 #undef VERSION /* If no OS set, compilation will fail by not knowing VERSION */
 
@@ -723,10 +723,10 @@ typedef struct alias {
 /* For a normal pattern, nmatch is no. of *'s. For a regular expression, it's
    -3 * (no. of capturing subexpressions): this is what pcre_exec needs. */
 
-typedef struct strpair {
+typedef struct strpairlist {
   char *name, *data;
-  struct strpair *next;
-} Strpair;
+  struct strpairlist *next;
+} Strpairlist;
 
 /*** typedef function pointers ***/
 
@@ -909,7 +909,7 @@ typedef struct {
   Include *link[GENREP_NUMBER];
   Strlist *expandhead[GENREP_NUMBER];
   char *baseurl;
-  logical searchconv;
+  choice searchconv;
   unsigned char convfloor;
 } Outchoices;
 
@@ -938,7 +938,7 @@ typedef struct {
   choice code2type[SC_NUMBER];
   logical succ304;
   Alias *aliashead[ITEM_NUMBER];
-  Strpair *searchengines, *intsearchengines;
+  Strpairlist *searchengines, *intsearchengines;
   Include *robots;
   Dateman dman;
   Outchoices outopts;
