@@ -1,4 +1,4 @@
-/***             analog 5.23             http://www.analog.cx/             ***/
+/***             analog 5.24             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -35,8 +35,8 @@ extern logical dnsresolve(char *name, choice level);
 extern void do_dns(char *name, char *alias, choice level);
 #endif
 extern void printalias(FILE *outf, Outchoices *od, char *name, AliasTo *to,
-  ptrdiff_t pmatch[]);
-extern void wildalias(char *name, AliasTo *to, ptrdiff_t pmatch[]);
+  int pmatch[]);
+extern void wildalias(char *name, AliasTo *to, int pmatch[]);
 extern choice prealias(Memman *mm, Memman *mmv, Hashentry *vhost, Memman *mmq,
   logical case_insensitive, char *prefix, size_t prefixlen, int pvpos,
   Include *argshead);
@@ -421,7 +421,7 @@ extern void report_fromto(Dateman *dman);
 extern void report_want(Include *wanthead, char *type, char *indent);
 extern void report_scwant(choice *code2type);
 extern void report_alias(Alias *aliashead, char *type, char *indent);
-extern void report_strpair(Strpair *head, char *type, char *connector);
+extern void report_strpairlist(Strpairlist *head, char *type, char *connector);
 extern void report_lowmem(choice lowmem[]);
 #ifndef NODNS
 extern void report_dns(void);
@@ -537,6 +537,7 @@ extern void strtolowerx(char *n);
 extern void toloweralias(Alias *ap, logical both);
 extern void tolowerinc(Include *ip);
 extern void reversealias(Alias **head);
+extern void reversestrpairlist(Strpairlist **head);
 extern logical strcaseeq(char *s, char *t);
 extern char *strrpbrk(char *s, char *t);
 #ifdef EBCDIC
@@ -570,8 +571,8 @@ extern void freemm(Memman *m);
 extern void *memmove(void *dst0, const void *src0, size_t length);
 #endif
 extern logical wildmatch(char *s, char *p, char *whole, int nmatch,
-  ptrdiff_t *pmatch);
-extern logical matchq(char *s, void *p, logical is_regex, ptrdiff_t *pmatch);
+  int *pmatch);
+extern logical matchq(char *s, void *p, logical is_regex, int *pmatch);
 extern logical genwildmatch(char *s, char *s2, char *p);
 extern logical headmatch(char *s, char *p);
 extern logical headcasematch(char *s, char *p);
