@@ -1,4 +1,4 @@
-/***             analog 5.23             http://www.analog.cx/             ***/
+/***             analog 5.24             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -61,7 +61,7 @@ char *byteprefix = " kMGTPEZY";  /* Room for growth :)  Note initial space */
 /* NB Output versions of the byte prefixes are in the language files */
 
 /* Domain levels; making this global is messy but easiest */
-Strpair **domlevels;
+Strpairlist **domlevels;
 
 /* Another messy one, but it's easier than always passing the charset around */
 htmlstrlenp htmlstrlen;
@@ -72,7 +72,7 @@ logical newloglist = TRUE, iscache = FALSE;
 int tz = 0, stz = 0;
 choice wantitem[INPUT_NUMBER];
 #ifndef NOPIPES
-Strpair *uncompresshead = NULL;
+Strpairlist *uncompresshead = NULL;
 #endif
 
 /* Debugging, warnings, pretty printing */
@@ -1839,7 +1839,7 @@ void defaults(Options *op) {
     op->outopts.tree[i]->space->first = NULL;
     op->outopts.tree[i]->space->alignment = ALIGNSIZE;
   }
-  domlevels = (Strpair **)xmalloc(DOMLEVEL_NUMBER * sizeof(Strpair *));
+  domlevels = (Strpairlist **)xmalloc(DOMLEVEL_NUMBER * sizeof(Strpairlist *));
   for (i = 0; i < DOMLEVEL_NUMBER; i++)
     domlevels[i] = NULL;
   op->outopts.tree[G(REP_REQ)]->cutfn = &rnextname;
