@@ -1,4 +1,4 @@
-/***             analog 5.23             http://www.analog.cx/             ***/
+/***             analog 5.24             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -834,14 +834,16 @@ void correct(Options *op) {
   toloweralias(od->aliashead[G(REP_VHOST)], FALSE);
   tolowerinc(op->wanthead[ITEM_VHOST]);
   tolowerinc(od->wanthead[G(REP_VHOST)]);
-  toloweralias(op->aliashead[ITEM_USER], TRUE);
-  toloweralias(od->aliashead[G(REP_USER)], FALSE);
-  toloweralias(od->aliashead[G(REP_FAILUSER)], FALSE);
-  tolowerinc(op->wanthead[ITEM_USER]);
-  tolowerinc(od->wanthead[G(REP_USER)]);
-  tolowerinc(od->wanthead[G(REP_FAILUSER)]);
   tolowerinc(od->wanthead[G(REP_SEARCHREP)]);
   tolowerinc(od->wanthead[G(REP_SEARCHSUM)]);
+  if (op->miscopts.usercase_insensitive) {
+    toloweralias(op->aliashead[ITEM_USER], TRUE);
+    toloweralias(od->aliashead[G(REP_USER)], FALSE);
+    toloweralias(od->aliashead[G(REP_FAILUSER)], FALSE);
+    tolowerinc(op->wanthead[ITEM_USER]);
+    tolowerinc(od->wanthead[G(REP_USER)]);
+    tolowerinc(od->wanthead[G(REP_FAILUSER)]);
+  }
   if (op->miscopts.case_insensitive) {
     toloweralias(op->aliashead[ITEM_FILE], TRUE);
     toloweralias(od->aliashead[G(REP_REQ)], FALSE);
@@ -850,7 +852,7 @@ void correct(Options *op) {
     toloweralias(od->aliashead[G(REP_TYPE)], FALSE);
     toloweralias(od->aliashead[G(REP_DIR)], FALSE);
     tolowerinc(op->wanthead[ITEM_FILE]);
-    tolowerinc(op->ispagehead);  /* this gets refs too, but shame... */
+    tolowerinc(op->ispagehead);
     tolowerinc(op->argshead);
     tolowerinc(od->wanthead[G(REP_REQ)]);
     tolowerinc(od->wanthead[G(REP_REDIR)]);
@@ -881,6 +883,9 @@ void finalinit(Options *op) {
   timecode_t timec, goodtimec, badtimec;
   char *name, *alias;
   choice rc;
+#endif
+#ifndef NOPIPES
+  extern Strpairlist *uncompresshead;
 #endif
   extern htmlstrlenp htmlstrlen;
   extern timecode_t starttimeuxc;
@@ -932,6 +937,10 @@ void finalinit(Options *op) {
     reversealias(&(op->aliashead[i]));
   for (i = 0; i < GENREP_NUMBER; i++)
     reversealias(&(od->aliashead[i]));
+  /* and swap uncompress list round */
+#ifndef NOPIPES
+  reversestrpairlist(&uncompresshead);
+#endif
   /* Translate filenames to put files in the correct directories */
   /* Also interpret %date codes and wild cards where appropriate */
   if (!strcaseeq(od->headerfile, "none") && !IS_STDIN(od->headerfile))
@@ -1073,8 +1082,9 @@ void finalinit(Options *op) {
 	 convert A0-FF for ISO-8859-*, 80-FF o/wise. This may still include
 	 some non-printable characters! But we can't have a table for every
 	 charset. */
-      if (!od->searchconv || od->multibyte ||
-	  strcaseeq(lngstr[charset_], "US-ASCII"))
+      if (od->searchconv == UNSET)
+	od->searchconv = !(od->multibyte);
+      if (!od->searchconv || strcaseeq(lngstr[charset_], "US-ASCII"))
 	od->convfloor = 0;
       else if (substrcaseeq(lngstr[charset_], "iso-8859-") ||
 	       strcaseeq(lngstr[charset_], "armscii-8"))
