@@ -1,4 +1,4 @@
-/***             analog 5.23             http://www.analog.cx/             ***/
+/***             analog 5.24             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -264,6 +264,8 @@ void configchoice(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
   }
   else if (STREQ(cmd, "WEEKBEGINSON"))
     choices = daychoices;
+  else if (STREQ(cmd, "SEARCHCHARCONVERT"))
+    choices = onoffchoices;
   else {
     choices = onoffchoices;
     islog = TRUE;
@@ -1488,8 +1490,8 @@ void configalias(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
 }
 
 void configstrpair(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
-  Strpair **pair = (Strpair **)opt;
-  Strpair *ap;
+  Strpairlist **pair = (Strpairlist **)opt;
+  Strpairlist *ap;
 
   if (rc == 0) {
     shortwarn(cmd, arg1, rc);
@@ -1510,13 +1512,13 @@ void configstrpair(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
     longwarn(cmd, arg1, arg2, rc);
 
   if (*pair == NULL) {
-    ap = (Strpair *)xmalloc(sizeof(Strpair));
+    ap = (Strpairlist *)xmalloc(sizeof(Strpairlist));
     *pair = ap;
   }
   else {
     for (ap = *pair; ap->next != NULL; TO_NEXT(ap))
       ;  /* find end of list */
-    ap->next = (Strpair *)xmalloc(sizeof(Strpair));
+    ap->next = (Strpairlist *)xmalloc(sizeof(Strpairlist));
     TO_NEXT(ap);
   }
   COPYSTR(ap->name, arg1);
@@ -1550,7 +1552,7 @@ void configstrpair2list(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
 }
 
 void configdomlevel(void *opt, char *cmd, char *arg1, char *arg2, int rc) {
-  Strpair ***levels = (Strpair ***)opt;
+  Strpairlist ***levels = (Strpairlist ***)opt;
   unsigned int c;
 
   c = 26 * ((int)(*arg1 - 'a'));
