@@ -1,4 +1,4 @@
-/***             analog 5.23             http://www.analog.cx/             ***/
+/***             analog 5.24             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -15,9 +15,9 @@ static logical stdin_used = FALSE;
 FILE *my_lfopen(Filelist *p, char *filetype)
 {             /* open for reading */
 #ifndef NOPIPES
-  extern Strpair *uncompresshead;
+  extern Strpairlist *uncompresshead;
   char *cmd;
-  Strpair *up;
+  Strpairlist *up;
 #endif
 
   FILE *f;
