@@ -1,4 +1,4 @@
-/***             analog 5.23             http://www.analog.cx/             ***/
+/***             analog 5.24             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -15,7 +15,7 @@ void report_vbles(Options *op) {
   extern unsigned long progressfreq;
   extern logical cgi, anywarns;
 #ifndef NOPIPES
-  extern Strpair *uncompresshead;
+  extern Strpairlist *uncompresshead;
 #endif
   int i;
 
@@ -38,7 +38,7 @@ void report_vbles(Options *op) {
   report_logfiles(op->miscopts.logfile[1], TRUE);
   report_logfiles(op->miscopts.logfile[0], FALSE);
 #ifndef NOPIPES
-  report_strpair(uncompresshead, "Uncompressing files", "by ");
+  report_strpairlist(uncompresshead, "Uncompressing files", "by ");
 #endif
   report_fromto(&(op->dman));
   if (stz != 0)
@@ -53,9 +53,10 @@ void report_vbles(Options *op) {
   if (op->outopts.repq[REP_OS])
     report_want(op->robots, "as robots", "");
   if (op->outopts.repq[REP_SEARCHREP] || op->outopts.repq[REP_SEARCHSUM])
-    report_strpair(op->searchengines, "Search engines", "arg=");
+    report_strpairlist(op->searchengines, "Search engines", "arg=");
   if (op->outopts.repq[REP_INTSEARCHREP] || op->outopts.repq[REP_INTSEARCHSUM])
-    report_strpair(op->intsearchengines, "Internal search engines", "arg=");
+    report_strpairlist(op->intsearchengines, "Internal search engines",
+		       "arg=");
   for (i = 0; i < ITEM_NUMBER; i++)
     report_alias(op->aliashead[i], item_type[i], "");
   report_lowmem(op->miscopts.lowmem);
@@ -395,8 +396,8 @@ void report_alias(Alias *aliashead, char *type, char *indent) {
   }
 }
 
-void report_strpair(Strpair *head, char *type, char *connector) {
-  Strpair *ap;
+void report_strpairlist(Strpairlist *head, char *type, char *connector) {
+  Strpairlist *ap;
 
   if (head != NULL) {
     printf("%s as follows:\n", type);
