@@ -1,4 +1,4 @@
-/***             analog 5.23             http://www.analog.cx/             ***/
+/***             analog 5.24             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -618,9 +618,9 @@ void snextname(char **name, char **nameend, char *whole, logical build) {
 void Znextname(char **name, char **nameend, char *whole, logical build) {
   static char *s1 = LNGSTR_NODOMAIN;
   static char *s2 = LNGSTR_UNKDOMAIN;
-  extern Strpair **domlevels;
+  extern Strpairlist **domlevels;
 
-  Strpair *ap;
+  Strpairlist *ap;
   unsigned int c;
 
   if (*name == NULL) {
@@ -764,7 +764,6 @@ void Bnextname(char **name, char **nameend, char *whole, void *arg) {
     if (((*name = strstr(whole, "Mosaic")) != NULL && (len = 6)) ||
 	((*name = strstr(whole, "mosaic")) != NULL && (len = 6)) ||
 	((*name = strstr(whole, "Konqueror")) != NULL && (len = 9)) ||
-	((*name = strstr(whole, "Netscape6")) != NULL && (len = 9)) ||
 	((*name = strstr(whole, "Galeon")) != NULL && (len = 6)) ||
 	((*name = strstr(whole, "WebTV")) != NULL && (len = 5)) ||
 	((*name = strstr(whole, "Opera")) != NULL && (len = 5)) ||
@@ -806,7 +805,7 @@ void Bnextname(char **name, char **nameend, char *whole, void *arg) {
 }
 
 void Pnextname(char **name, char **nameend, char *whole, void *arg) {
-  char *c;
+  char *c, *d;
 
   if (*name == NULL) {
     if (arg != NULL && included(whole, FALSE, (Include *)arg)) {
@@ -816,15 +815,28 @@ void Pnextname(char **name, char **nameend, char *whole, void *arg) {
     }
     if (headmatch(whole, "Mozilla"))
 	whole += 7;  /* just to save searching time */
+
+    /* First find Windows versions, starting with "Windows" or "WinNT" or
+       "Win9" */
     if ((c = strstr(whole, "Windows")) != NULL) {
       c += 7;
+      if (*c == ';') {
+	/* Mozilla/5 uses strings like "Windows; U; Win98" so we have to look
+	   for the second Windows or Win. */
+	if ((d = strstr(c + 1, "Windows")) != NULL)
+	  c = d + 7;
+	else if ((d = strstr(c + 1, "WinNT")) != NULL ||
+		 (d = strstr(c + 1, "Win9")) != NULL)
+	  c = d + 3;
+      }
       if (*c == ' ')
 	c++;
     }
-    else if ((c = strstr(whole, "Win")) != NULL &&
-	     (ISDIGIT(*(c + 3)) || *(c + 3) == 'N'))
+    else if ((c = strstr(whole, "WinNT")) != NULL ||
+	     (c = strstr(whole, "Win9")) != NULL)
       c += 3;
-    if (c != NULL) {
+
+    if (c != NULL) {  /* We did find "Windows" or "Win" */
       if (*c == '9' && *(c + 1) == '5')
 	  *name = "Windows:Windows 95";
       else if (*c == '9' && *(c + 1) == '8') {
@@ -873,6 +885,8 @@ void Pnextname(char **name, char **nameend, char *whole, void *arg) {
       else
 	*name = "Windows:Unknown Windows";
     }
+
+    /* Now non-Windows operating systems */
     else if ((c = strstr(whole, "Mac")) != NULL) {
       if (strstr(c + 3, "68"))
 	*name = "Macintosh:Macintosh 68k";
@@ -923,14 +937,14 @@ void Pnextname(char **name, char **nameend, char *whole, void *arg) {
 void Nnextname(char **name, char **nameend, char *whole, void *arg) {
   /* NB Quite a lot is held over to do_aliasN(), which is called from
      hashfind(), from makederived() */
-  Strpair *al;
+  Strpairlist *al;
   char *c, *d;
   logical done;
 
   if (*name == NULL) {
     if ((d = strchr(whole, '?')) != NULL && *(d + 1) != '\0') {
       *d = '\0';
-      for (al = (Strpair *)arg, done = FALSE; al != NULL && !done;
+      for (al = (Strpairlist *)arg, done = FALSE; al != NULL && !done;
 	   TO_NEXT(al)) {
 	if (MATCHES(whole, al->name)) {  /* find right engine in list */
 	  for (c = d; c != NULL && !done; c = strpbrk(c, "&;")) {
