@@ -1,4 +1,4 @@
-/***             analog 5.23             http://www.analog.cx/             ***/
+/***             analog 5.24             http://www.analog.cx/             ***/
 /*** This program is copyright (c) Stephen R. E. Turner 1995 - 2002 except as
  *** stated otherwise. Distribution, usage and modification of this program is
  *** subject to the conditions of the Licence which you should have received
@@ -151,6 +151,18 @@ void reversealias(Alias **head) {
   *head = lastap;
 }
 
+/* Swap an strpairlist round. Same as reversealias. Who needs templates?? */
+void reversestrpairlist(Strpairlist **head) {
+  Strpairlist *sp, *lastsp = NULL, *nextsp;
+
+  for (sp = *head; sp != NULL; sp = nextsp) {
+    nextsp = sp->next;
+    sp->next = lastsp;
+    lastsp = sp;
+  }
+  *head = lastsp;
+}
+
 logical strcaseeq(char *s, char *t) {
   for ( ; TOUPPER(*s) == TOUPPER(*t) && *s != '\0'; s++, t++)
     ;
@@ -622,12 +634,12 @@ void *memmove(void *dst0, const void *src0, size_t length) {
 
 #define SETPMATCH(ptr1, ptr2) \
   if (nmatch > 0) { \
-    pmatch[0] = ptr1 - whole; \
-    pmatch[1] = ptr2 - whole; \
+    pmatch[0] = (int)(ptr1 - whole); \
+    pmatch[1] = (int)(ptr2 - whole); \
   }
 
-logical wildmatch(char *s, char *p, char *whole, int nmatch,
-		  ptrdiff_t *pmatch) {  /* match string s against pattern p */
+/* match string s against pattern p */
+logical wildmatch(char *s, char *p, char *whole, int nmatch, int *pmatch) {
   char *ss, *pp;
 
   /* First match head portions */
@@ -680,9 +692,9 @@ logical wildmatch(char *s, char *p, char *whole, int nmatch,
   return(FALSE);
 }
 
-logical matchq(char *s, void *p, logical is_regex, ptrdiff_t *pmatch) {
+logical matchq(char *s, void *p, logical is_regex, int *pmatch) {
   if (is_regex)
-    return(pcre_exec((pcre *)p, NULL, s, (int)strlen(s), 0, 0, (int *)pmatch,
+    return(pcre_exec((pcre *)p, NULL, s, (int)strlen(s), 0, 0, pmatch,
 		     (pmatch == NULL)?0:PMATCH_SIZE) >= 0);
   else
     return(wildmatch(s, (char *)p, s, (pmatch == NULL)?0:PMATCH_SIZE, pmatch));
